@@ -15,18 +15,13 @@
  *  along with this program; if not, write to the Free Software
  *  Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301, USA.
  *
- *  $Id: ephy-stock-icons.c 7191 2007-07-21 13:36:40Z wbolster $
  */
 
 #include "config.h"
 
 #include <gtk/gtk.h>
-#include <glib.h>
-#include <stdio.h>
-#include <string.h>
 #include <glib/gi18n.h>
 
-#include "ephy-file-helpers.h"
 #include "ephy-stock-icons.h"
 
 void
