@@ -191,7 +191,7 @@ gtk_tree_view_vertical_autoscroll (GtkTreeView *tree_view)
 	float value;
 	
 	window = gtk_tree_view_get_bin_window (tree_view);
-	vadjustment = gtk_tree_view_get_vadjustment (tree_view);
+	vadjustment = gtk_scrollable_get_vadjustment (GTK_SCROLLABLE (tree_view));
 	
 	gdk_window_get_pointer (window, NULL, &y, NULL);
 	
@@ -506,7 +506,7 @@ filter_changed_cb (EphyNodeFilter *filter,
 
 		cursor = gdk_cursor_new (GDK_WATCH);
 		gdk_window_set_cursor (gdk_window, cursor);
-		gdk_cursor_unref (cursor);
+		g_object_unref (cursor);
 
 		gdk_flush ();
 
