@@ -79,7 +79,7 @@ drag_data_received_cb (GtkWidget *widget,
 	
 	topic = ephy_topic_action_get_topic (EPHY_TOPIC_ACTION (action));
 	
-	data = (char *)selection_data->data;
+	data = (char *) gtk_selection_data_get_data (selection_data);
 	bookmarks = ephy_shell_get_bookmarks (ephy_shell);
 	
 	netscape_url = g_strsplit (data, "\n", 2);
@@ -165,7 +165,7 @@ ephy_topic_action_sync_label (GtkAction *action,
 	}
 	else if (GTK_IS_MENU_ITEM (proxy))
 	{
-		label = GTK_BIN (proxy)->child;
+		label = gtk_bin_get_child (GTK_BIN (proxy));
 	}
 	else
 	{
@@ -284,7 +284,6 @@ button_deactivate_cb (GtkMenuShell *ms,
 	GtkWidget *window = gtk_widget_get_ancestor (button, GTK_TYPE_WINDOW);
 
 	gtk_toggle_button_set_active (GTK_TOGGLE_BUTTON (button), FALSE);
-	gtk_button_released (GTK_BUTTON (button));
 
 	g_object_set_data (G_OBJECT (window),
 			   "active-topic-action-button", NULL);
@@ -374,7 +373,10 @@ button_enter_cb (GtkWidget *button,
 	    gtk_toggle_button_get_active (GTK_TOGGLE_BUTTON (active_button)))
 	{
 		EphyTopicAction *active_action;
-		active_action = (EphyTopicAction*)gtk_activatable_get_related_action (GTK_ACTIVATABLE (active_button));
+		GtkWidget *ancestor;
+
+		ancestor = gtk_widget_get_ancestor (active_button, GTK_TYPE_TOOL_ITEM);
+		active_action = (EphyTopicAction*)gtk_activatable_get_related_action (GTK_ACTIVATABLE (ancestor));
 
 		erase_popup (active_action);
 		gtk_toggle_button_set_active (GTK_TOGGLE_BUTTON (active_button), FALSE);
