@@ -68,8 +68,8 @@ typedef enum
 	EPHY_NEW_TAB_IN_EXISTING_WINDOW	= 1 << 11,
 
 	/* The way to load */
-	EPHY_NEW_TAB_ALLOW_FIXUP	= 1 << 12,
-	EPHY_NEW_TAB_FROM_EXTERNAL      = 1 << 13,
+	EPHY_NEW_TAB_FROM_EXTERNAL      = 1 << 12,
+	EPHY_NEW_TAB_DONT_COPY_HISTORY  = 1 << 13,
 	
 } EphyNewTabFlags;
 
